@@ -4,6 +4,7 @@ import math
 import random
 from collections import OrderedDict
 import re
+import uuid
 
 from dateutil.parser import parse
 
@@ -175,6 +176,53 @@ class Player(Base):
             return None
         return cls.load_one(ids[0])
 
+    @classmethod
+    def make_random(cls, name="Random Player", seed=None):
+        """
+        Generate a completely random player.
+        """
+        rng = random.Random(seed)
+        if seed:
+            id = uuid.uuid3(uuid.NAMESPACE_X500, name=str(seed))
+        else:
+            id = uuid.uuid4()
+
+        return Player({
+            'name': name,
+            'id': str(id),
+            'baseThirst': rng.random(),
+            'continuation': rng.random(),
+            'groundFriction': rng.random(),
+            'indulgence': rng.random(),
+            'laserlikeness': rng.random(),
+            'divinity': rng.random(),
+            'martyrdom': rng.random(),
+            'moxie': rng.random(),
+            'musclitude': rng.random(),
+            'patheticism': rng.random(),
+            'thwackability': rng.random(),
+            'tragicness': rng.random(),
+            'anticapitalism': rng.random(),
+            'chasiness': rng.random(),
+            'omniscience': rng.random(),
+            'tenaciousness': rng.random(),
+            'watchfulness': rng.random(),
+            'coldness': rng.random(),
+            'overpowerment': rng.random(),
+            'ruthlessness': rng.random(),
+            'shakespearianism': rng.random(),
+            'unthwackability': rng.random(),
+            'suppression': rng.random(),
+            'buoyancy': rng.random(),
+            'cinnamon': rng.random(),
+            'deceased': False,
+            'peanutAllergy': rng.random() > .25,
+            'pressurization': rng.random(),
+            'soul': rng.randint(2, 9),
+            'totalFingers': rng.randint(9, 42),
+            'fate': rng.randint(1,99),
+        })
+
     @property
     def hitting_rating(self):
         if getattr(self, "_hitting_rating", None):
@@ -473,7 +521,7 @@ class Player(Base):
         for b_key, b_val in buffs.items():
             if b_key in ('batting_rating', 'overall_rating'):
                 original_json['tragicness'] = min(0.99, max(0.01, original_json['tragicness'] - b_val))
-                original_json['patheticism'] = min(0.99, original_json['patheticism'] - b_val)
+                original_json['patheticism'] = min(0.99, max(0.01, original_json['patheticism'] - b_val))
                 original_json['thwackability'] = max(0.01, original_json['thwackability'] + b_val)
                 original_json['divinity'] = max(0.01, original_json['divinity'] + b_val)
                 original_json['moxie'] = max(0.01, original_json['moxie'] + b_val)
@@ -915,6 +963,12 @@ class Game(Base):
             game["gameId"]: cls(game["data"]) for game in chronicler.get_games(team_ids=team_id, season=season, day=day)
         }
 
+    @classmethod
+    def load_by_tournament(cls, tournament, team_id=None, day=None):
+        return {
+            game["gameId"]: cls(game["data"]) for game in chronicler.get_games(team_ids=team_id, tournament=tournament, day=day)
+        }
+
     @property
     def winning_team(self):
         return self.home_team if self.home_score > self.away_score else self.away_team
